@@ -3,11 +3,15 @@
 
 void Loop::screening()
 {
+    if (d_status == PRESENT and d_nRounds > 0)
+        g_log << "\nLoop::screening";
+
     for (d_round = 0; d_status == PRESENT and d_round != d_nRounds; ++d_round)
     {
         double screeningAge = d_screening.roundAge(d_round);
+        g_log << "\n  screening at age " << screeningAge << '\n';
 
-        if (leaving(screeningAge))
+        if (leaving(screeningAge))      // the case has died
             return;
 
 xerr("round: " << d_round);
