@@ -3,7 +3,7 @@
 
 void Scenario::setDeath()
 {
-    bool ok = true;
+    LineInfo const *previous = 0;
 
     string cumDeath;
     if (cumDeath = Options::instance().cumDeathFile(); not cumDeath.empty())
@@ -19,12 +19,12 @@ void Scenario::setDeath()
         else
         {
             cumDeath = "analysis specification";
-            lines.get();                        // skip the first (empty) line
-            while (LineInfo const *ptr = lines.get())
-                ok = appendCumDeath(ptr->tail) and ok;
+            LineInfo const *ptr = lines.get();  // skip the first (empty) line
+            do
+                previous = ptr;                 // keep the previous line
+            while ((ptr = lines.get()) and appendCumDeath(ptr->tail));
         }
     }
 
-    if (ok)
-        checkCumDeath(cumDeath);
+    checkCumDeath(cumDeath, previous);
 }
